Project Info
===============================================================================

=============== ===============================================================
Category        Hyperlink
=============== ===============================================================
Documentation:  See README_
Download:       http://pypi.python.org/pypi/click-configfile (or: `github archive`_)
Development:    https://github.com/click-contrib/click-configfile
Issue Tracker:  https://github.com/click-contrib/click-configfile/issues
=============== ===============================================================

.. hint::

    The PyPI version is the latest stable version.
    Otherwise, use the latest stable tag or the "bleeding edge" from Github.

.. _`github archive`: https://github.com/click-contrib/click-configfile/tags
.. _README: README.rst
